{% load static %}
<!-- Start FontAwesome CSS from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/css/fontawesome/5.14.0/all.min.css' %}"/>
<!-- End FontAwesome CSS from aa-gdpr -->