{% load static %}
<!-- Start X-editable CSS from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/css/x-editable/1.5.1/bootstrap-editable.css' %}"/>
<!-- End X-editable CSS from aa-gdpr -->