{% load static %}
<!-- Start Bootstrap + jQuery js from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/js/jquery/2.2.4/jquery.min.js' %}"></script>
<script type="application/javascript" src="{% static 'aagdpr/js/twitter-bootstrap/3.4.1/bootstrap.min.js' %}"></script>
<!-- End Bootstrap + jQuery js from aa-gdpr -->