{% load static %}
<!-- Start X-editable JS from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/js/x-editable/1.5.1/bootstrap-editable.min.js' %}"></script>
<!-- End X-editable JS from aa-gdpr -->
