{% load static %}
<!-- Start Datatables-js from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/js/datatables/1.10.21/jquery.dataTables.min.js' %}"></script>
<script type="application/javascript" src="{% static 'aagdpr/js/datatables/1.10.21/dataTables.bootstrap.min.js' %}"></script>
<!-- End Datatables-js from aa-gdpr -->