{% load static %}
<!-- Start jQuery-DateTimePicker CSS from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/css/jquery-datetimepicker/2.5.20/jquery.datetimepicker.min.css' %}"/>
<!-- End jQuery-DateTimePicker CSS from aa-gdpr -->