{% load static %}
<!-- Start Datatables-css from aa-gdpr -->
<link rel="stylesheet" type="text/css" href="{% static 'aagdpr/css/datatables/1.10.21/dataTables.bootstrap.min.css' %}"/>
<!-- End Datatables-css from aa-gdpr -->