{% load static %}
<!-- Start Clipboard.js js from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/js/clipboard.js/2.0.6/clipboard.min.js' %}"></script>
<!-- End Clipboard.js js from aa-gdpr -->