{% load static %}
<!-- Start jQuery-DateTimePicker JS from aa-gdpr -->
<script type="application/javascript" src="{% static 'aagdpr/js/jquery-datetimepicker/2.5.20/jquery.datetimepicker.full.min.js' %}"></script>
<!-- End jQuery-DateTimePicker JS from aa-gdpr -->